@@ -27,7 +27,7 @@ import socket
 from cert_cmd import find_cert_id
 
 
-class ProcessStatus:
+class ProcessStatus(object):
     SuccessFinished = 0
     Worked = 1
     FailedFinished = 2
@@ -35,7 +35,7 @@ class ProcessStatus:
     Paused = 4
 
 
-class ProcessMode:
+class ProcessMode(object):
     CoreDaemon = "core"
     LocalCall = "local"
 
@@ -96,7 +96,7 @@ def search_worked_process2(clVars, filter_func=lambda x: True,
                     if cmdline and any(x in cmdline
                                        for x in get_symlink_commands()):
                         yield status['os_pid']
-        except (socket.error, ValueError, KeyError, EOFError, OSError) as e:
+        except (socket.error, ValueError, KeyError, EOFError, OSError):
             pass
 
 
@@ -110,7 +110,7 @@ def get_pid_info(clVars, statuses=(ProcessStatus.Worked,)):
         for pidfile in listDirectory(pids, fullPath=True):
             try:
                 status = pickle.load(open(pidfile))
-                if (status['status'] in statuses):
+                if status['status'] in statuses:
                     if path.exists(path.join("/proc", str(status['os_pid']))):
                         yield status
             except (socket.error, ValueError, KeyError, EOFError, OSError):
@@ -136,7 +136,7 @@ def clear_finished_pids(clVars):
             d = pickle.load(open(pidfile))
             if path.exists(path.join("/proc", str(d['os_pid']))):
                 continue
-        except BaseException:
+        except Exception:
             pass
         with ignore(OSError):
             os.unlink(pidfile)
@@ -172,7 +172,7 @@ class CoreWsdl(CoreServiceInterface):
                 if path.exists(rm_fn):
                     os.unlink(rm_fn)
             return 0
-        except BaseException as e:
+        except Exception:
             return 1
 
     # find process id in file processes, 1 - yes, 0 - none
@@ -189,7 +189,7 @@ class CoreWsdl(CoreServiceInterface):
             for line in t.splitlines():
                 try:
                     temp_line = int(line)
-                except:
+                except ValueError:
                     pass
                 # if process id found
                 if temp_line == find_pid:
@@ -229,14 +229,14 @@ class CoreWsdl(CoreServiceInterface):
         # create, if file not exists
         if not os.path.exists(self.sids_file):
             return 0
-        #            temp = open(self.sids_file, 'w')
+        # temp = open(self.sids_file, 'w')
         #            temp.close()
         fd = open(self.sids_file, 'r')
         while 1:
             try:
                 # read all on one record
                 list_sid = pickle.load(fd)
-            except:
+            except (EOFError, KeyError, IOError):
                 break
             # when session id equal readable...
             if int(sid) == int(list_sid[0]):
@@ -257,7 +257,7 @@ class CoreWsdl(CoreServiceInterface):
         # write complete flag (pid_list[6] = 1) in process file
         if not os.path.exists(self.pids):
             os.mkdir(self.pids)
-        if not self.process_pid.has_key(pid):
+        if pid not in self.process_pid:
             return 3
         meth = self.process_pid[pid]
         if meth.is_alive():
