@@ -291,7 +291,8 @@ class Wsdl(WsdlBase):
             'groups': [
                 lambda group: group(_("Group details"),
                                     normal=(
-                                    'cl_core_group', 'cl_core_group_rights'),
+                                        'cl_core_group',
+                                        'cl_core_group_rights'),
                                     custom_buttons=[('but0', _("Back"),
                                                      "core_group_show",
                                                      "button"),
@@ -332,7 +333,8 @@ class Wsdl(WsdlBase):
             'groups': [
                 lambda group: group(_("Modify group"),
                                     normal=(
-                                    'cl_core_group', 'cl_core_group_rights'),
+                                        'cl_core_group',
+                                        'cl_core_group_rights'),
                                     next_label=_("Done"),
                                     custom_buttons=[('but2', _("Confirm"),
                                                      'core_change_group',
@@ -368,7 +370,8 @@ class Wsdl(WsdlBase):
             'groups': [
                 lambda group: group(_("Add a group"),
                                     normal=(
-                                    'cl_core_group', 'cl_core_group_rights'),
+                                        'cl_core_group',
+                                        'cl_core_group_rights'),
                                     next_label=_("Add"))]},
         #
         # Удалить группу
@@ -605,7 +608,8 @@ class Wsdl(WsdlBase):
             'groups': [
                 lambda group: group(_("Setup variables"),
                                     normal=(
-                                    'cl_variable_filter', 'cl_variable_show'),
+                                        'cl_variable_filter',
+                                        'cl_variable_show'),
                                     next_label=_("Show"))]},
         #
         # отобразить переменные
@@ -638,12 +642,12 @@ class Wsdl(WsdlBase):
             'groups': [
                 lambda group: group(_("Custom action"),
                                     normal=(
-                                    'ac_custom_name', 'cl_human_edit_set',
-                                    'cl_verbose_set'),
+                                        'ac_custom_name', 'cl_human_edit_set',
+                                        'cl_verbose_set'),
                                     expert=(
-                                    'ur_core_login', 'cl_core_arch_machine',
-                                    'cl_templates_locate',
-                                    'cl_dispatch_conf'),
+                                        'ur_core_login', 'cl_core_arch_machine',
+                                        'cl_templates_locate',
+                                        'cl_dispatch_conf'),
                                     next_label=_("Perform"))]},
         #
         # перезапустить сервис calculate core
